==> ejc-assistrmat-impl-3.0.0-20220908.062627-175-sources.jar: com/ejianc/business/outrmat/order/bean/OutRmatOrderDetailEntity.java <==
package com.ejianc.business.outrmat.order.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 租赁订单明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_outrmat_order_detail")
public class OutRmatOrderDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="order_id")
    private Long orderId; // 订单主键ID
    @TableField(value="material_id")
    private Long materialId; // 物资主键
    @TableField(value="material_source_id")
    private String materialSourceId; // 物资来源主键
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="unit_id")
    private Long unitId; // 单位id
    @TableField(value="unit_name")
    private String unitName; // 单位名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="plan_nums_sum")
    private BigDecimal planNumsSum; // 计划数量
    @TableField(value="receive_nums_sum")
    private BigDecimal receiveNumsSum; // 接收数量
    @TableField(value="contract_nums_sum")
    private BigDecimal contractNumsSum; // 合同数量
    @TableField(value="contract_surplus_nums_sum")
    private BigDecimal contractSurplusNumsSum; // 合同剩余量
    @TableField(value="price")
    private BigDecimal price; // 单价
    @TableField(value="mny")
    private BigDecimal mny; // 金额
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="not_delivered_nums_sum")
    private BigDecimal notDeliveredNumsSum; // 未送货数量
    @TableField(value="delivered_nums_sum")
    private BigDecimal deliveredNumsSum; // 送货数量
    @TableField(value="detail_type")
    private Integer detailType; // 材料明细类型(1-价拨材料，2-租赁材料)
    @TableField(value="rent_calculation_type")
    private String rentCalculationType; // 计租方式：0-日租，1-月租，2-工程量租
    @TableField(value="unit_m_id")
    private Long unitMId; // 主单位
    @TableField(value="unit_m_name")
    private String unitMName; // 主单位名称


    public Long getUnitMId() {
        return unitMId;
    }

    public void setUnitMId(Long unitMId) {
        this.unitMId = unitMId;
    }

    public String getUnitMName() {
        return unitMName;
    }

    public void setUnitMName(String unitMName) {
        this.unitMName = unitMName;
    }

    public Long getOrderId() {
        return orderId;
    }

    public void setOrderId(Long orderId) {
        this.orderId = orderId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public BigDecimal getPlanNumsSum() {
        return planNumsSum;
    }

    public void setPlanNumsSum(BigDecimal planNumsSum) {
        this.planNumsSum = planNumsSum;
    }
    public BigDecimal getReceiveNumsSum() {
        return receiveNumsSum;
    }

    public void setReceiveNumsSum(BigDecimal receiveNumsSum) {
        this.receiveNumsSum = receiveNumsSum;
    }
    public BigDecimal getContractNumsSum() {
        return contractNumsSum;
    }

    public void setContractNumsSum(BigDecimal contractNumsSum) {
        this.contractNumsSum = contractNumsSum;
    }
    public BigDecimal getContractSurplusNumsSum() {
        return contractSurplusNumsSum;
    }

    public void setContractSurplusNumsSum(BigDecimal contractSurplusNumsSum) {
        this.contractSurplusNumsSum = contractSurplusNumsSum;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public BigDecimal getNotDeliveredNumsSum() {
        return notDeliveredNumsSum;
    }

    public void setNotDeliveredNumsSum(BigDecimal notDeliveredNumsSum) {
        this.notDeliveredNumsSum = notDeliveredNumsSum;
    }
    public Integer getDetailType() {
        return detailType;
    }

    public void setDetailType(Integer detailType) {
        this.detailType = detailType;
    }
    public String getRentCalculationType() {
        return rentCalculationType;
    }

    public void setRentCalculationType(String rentCalculationType) {
        this.rentCalculationType = rentCalculationType;
    }

    public BigDecimal getDeliveredNumsSum() {
        return deliveredNumsSum;
    }

    public void setDeliveredNumsSum(BigDecimal deliveredNumsSum) {
        this.deliveredNumsSum = deliveredNumsSum;
    }
}

==> ejc-assistrmat-impl-3.0.0-20221208.070609-326-sources.jar: com/ejianc/business/outrmat/order/bean/OutRmatOrderDetailEntity.java <==
package com.ejianc.business.outrmat.order.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 租赁订单明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_outrmat_order_detail")
public class OutRmatOrderDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="order_id")
    private Long orderId; // 订单主键ID
    @TableField(value="material_id")
    private Long materialId; // 物资主键
    @TableField(value="material_source_id")
    private String materialSourceId; // 物资来源主键
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="unit_id")
    private Long unitId; // 计租单位id
    @TableField(value="unit_name")
    private String unitName; // 计租单位名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="plan_nums_sum")
    private BigDecimal planNumsSum; // 计划数量
    @TableField(value="receive_nums_sum")
    private BigDecimal receiveNumsSum; // 接收数量
    @TableField(value="contract_nums_sum")
    private BigDecimal contractNumsSum; // 合同数量
    @TableField(value="contract_surplus_nums_sum")
    private BigDecimal contractSurplusNumsSum; // 合同剩余量
    @TableField(value="price")
    private BigDecimal price; // 单价
    @TableField(value="mny")
    private BigDecimal mny; // 金额
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="not_delivered_nums_sum")
    private BigDecimal notDeliveredNumsSum; // 未送货数量
    @TableField(value="delivered_nums_sum")
    private BigDecimal deliveredNumsSum; // 送货数量
    @TableField(value="detail_type")
    private Integer detailType; // 材料明细类型(1-价拨材料，2-租赁材料)
    @TableField(value="rent_calculation_type")
    private String rentCalculationType; // 计租方式：0-日租，1-月租，2-工程量租
    @TableField(value="unit_m_id")
    private Long unitMId; // 计量单位
    @TableField(value="unit_m_name")
    private String unitMName; // 计量单位


    public Long getUnitMId() {
        return unitMId;
    }

    public void setUnitMId(Long unitMId) {
        this.unitMId = unitMId;
    }

    public String getUnitMName() {
        return unitMName;
    }

    public void setUnitMName(String unitMName) {
        this.unitMName = unitMName;
    }

    public Long getOrderId() {
        return orderId;
    }

    public void setOrderId(Long orderId) {
        this.orderId = orderId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public BigDecimal getPlanNumsSum() {
        return planNumsSum;
    }

    public void setPlanNumsSum(BigDecimal planNumsSum) {
        this.planNumsSum = planNumsSum;
    }
    public BigDecimal getReceiveNumsSum() {
        return receiveNumsSum;
    }

    public void setReceiveNumsSum(BigDecimal receiveNumsSum) {
        this.receiveNumsSum = receiveNumsSum;
    }
    public BigDecimal getContractNumsSum() {
        return contractNumsSum;
    }

    public void setContractNumsSum(BigDecimal contractNumsSum) {
        this.contractNumsSum = contractNumsSum;
    }
    public BigDecimal getContractSurplusNumsSum() {
        return contractSurplusNumsSum;
    }

    public void setContractSurplusNumsSum(BigDecimal contractSurplusNumsSum) {
        this.contractSurplusNumsSum = contractSurplusNumsSum;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public BigDecimal getNotDeliveredNumsSum() {
        return notDeliveredNumsSum;
    }

    public void setNotDeliveredNumsSum(BigDecimal notDeliveredNumsSum) {
        this.notDeliveredNumsSum = notDeliveredNumsSum;
    }
    public Integer getDetailType() {
        return detailType;
    }

    public void setDetailType(Integer detailType) {
        this.detailType = detailType;
    }
    public String getRentCalculationType() {
        return rentCalculationType;
    }

    public void setRentCalculationType(String rentCalculationType) {
        this.rentCalculationType = rentCalculationType;
    }

    public BigDecimal getDeliveredNumsSum() {
        return deliveredNumsSum;
    }

    public void setDeliveredNumsSum(BigDecimal deliveredNumsSum) {
        this.deliveredNumsSum = deliveredNumsSum;
    }
}
